# VisionRPA 
This package is use for auto clicking and auto writing


## requirements
* Operating System
  * Windows
* Programming Language
  * python 3.7

## Usage
* First open this link [link ]( https://www3.ntu.edu.sg/home/ehchua/programming/webprogramming/jsdemo/JSFormValidation.html) make sure it remain open
* then

```python
from VisionRPA import VisionUI 

app='HTML Form Input Validation Using JavaScript - Google Chrome'
dictionary_data=VisionUI.Get_RT_app_elements('Vision-416',app) 

action='write'
VisionUI.add_action('click',dictionary_data,app,index_no=6,enter_text='0000@gmail.com')
VisionUI.add_action(action,dictionary_data,app,label_='Name',enter_text='test1')
VisionUI.add_action(action,dictionary_data,app,label_='Address',enter_text='1234')
VisionUI.add_action(action,dictionary_data,app,label_='Zip Code*',enter_text='12345')

VisionUI.add_action('click',dictionary_data,app,label_='Country*')
VisionUI.add_action(action,dictionary_data,app,label_='Country*',enter_text='BB')
VisionUI.add_action('click',dictionary_data,app,label_='Male')
VisionUI.add_action('click',dictionary_data,app,label_='Blue')
VisionUI.add_action(action,dictionary_data,app,label_='Phone',enter_text='0000')
VisionUI.add_action(action,dictionary_data,app,label_='Email*',enter_text='0000@gmail.com')
VisionUI.add_action(action,dictionary_data,app,label_='Password (6-8 characters)*',enter_text='0000000')
VisionUI.add_action(action,dictionary_data,app,label_='Verify Password*',enter_text='0000000')
VisionUI.add_action('click',dictionary_data,app,index_no=7) 
```
